@@ -11,7 +11,9 @@ class NetBoxAttachmentsConfig(PluginConfig):
     author = 'Jan Krupa'
     base_url = 'netbox-attachments'
     default_settings = {
-        'apps': ['dcim', 'ipam', 'circuits', 'tenancy', 'virtualization', 'wireless']
+        'apps': ['dcim', 'ipam', 'circuits', 'tenancy', 'virtualization', 'wireless'],
+        'display_default': "right_page",
+        'display_setting': {}
     }
     required_settings = []
     min_version = '3.3.4'
